import React, { useState, useEffect } from 'react';
import {
    Form,
    Modal,
    Space,
    Table,
    Button,
    Popconfirm,
    Spin,
    notification,
} from 'antd';

import { reloadTableFields, removeFields } from '@/services/platform/bs';
import FieldEditor from './fieldEditor';
import { useHistory } from 'react-router-dom';
import styles from './index.less'
const AddModal = props => {
    const history = useHistory();
    const [tableData, setTableData] = useState([]);
    const { callBackSubmit = () => { }, type, visible } = props;
    const [loading, setLoading] = useState(false);
    const [treeLoading, setTreeLoading] = useState(false);
    const [formObj, setFormObj] = useState('');
    const [form] = Form.useForm();
    const [flag, setFlag] = useState(0); // 弹窗类型
    const [isVisible, setIsVisible] = useState(false); // 弹窗
    const [isType, setIsType] = useState(''); // 弹窗类型
    const [itemData, setItemData] = useState({});
    const { Item } = Form;
    // 提交
    const onSubmit = () => {
        form.validateFields().then(validate => {
            if (validate) {
                setLoading(true);
                let obj = form.getFieldsValue();
            }
        });
    };
    const columns = [
        {
            title: '字段名',
            dataIndex: 'name',
            key: 'name',
            width: 150,
            render: text => <a>{text}</a>,
        },
        {
            title: '别名',
            dataIndex: 'alias',
            key: 'alias',
            align: 'center',
        },
        {
            title: '字段类型',
            dataIndex: 'storeType',
            key: 'storeType',
            align: 'center',
        },
        {
            title: '形态',
            dataIndex: 'shape',
            key: 'shape',
            align: 'center',
        },
        {
            title: '配置',
            dataIndex: 'config',
            key: 'config',
            align: 'center',
        },

        {
            title: '只读',
            dataIndex: 'readOnly',
            key: 'readOnly',
            align: 'center',
        },
        {
            title: '同步',
            dataIndex: 'syncEvent',
            key: 'syncEvent',
            align: 'center',
        },
        {
            title: '操作',
            width: 250,
            ellipsis: true,
            align: 'center',
            render: (text, record) => (
                <Space>
                    <Button
                        type="primary"
                        size="small"
                        onClick={() => {
                            editor(record);
                        }}
                    >
                        编辑
                    </Button>
                    <div onClick={e => e.stopPropagation()}>
                        <Popconfirm
                            title="是否删除该字段？"
                            okText="确认"
                            cancelText="取消"
                            onConfirm={() => {
                                deleteChart(record);
                            }}
                        >
                            <Button size="small" danger>
                                删除
                            </Button>
                        </Popconfirm>
                    </div>
                </Space>
            ),
        },
    ];
    const editor = record => {
        setIsType('edit');
        setIsVisible(true);
        setItemData(record);
    };
    const Submit = prop => {
        setIsVisible(false);
        setFlag(flag + 1);
    };
    useEffect(() => {
        if (props.match.params.id) {
            setFormObj(props.match.params.id)
            setTreeLoading(true);
            reloadTableFields({
                tableName: props.match.params.id,
            }).then(res => {
                setTreeLoading(false);
                if (res.msg === 'Ok') {
                    setTableData(res.data.root);
               
                    console.log(formateArrDataA(res.data.root,'groupName'));
                }
            });
        }
    }, [flag]);
    const formateArrDataA = (initialArr, name) => {
        // 判定传参是否符合规则
        if (!(initialArr instanceof Array)) {
            return '请传入正确格式的数组'
        }
        if (!name) {
            return '请传入对象属性'
        }
        //先获取一下这个数组中有多少个"name"
        let nameArr = []
        for (let i in initialArr) {
            if (nameArr.indexOf(initialArr[i][`${name}`]) === -1) {
                nameArr.push(initialArr[i][`${name}`])
            }
        }
        //新建一个包含多个list的结果对象
        let tempObj = {}
        // 根据不同的"name"生成多个数组
        for (let k in nameArr) {
            for (let j in initialArr) {
                if (initialArr[j][`${name}`] == nameArr[k]) {
                    // 每次外循环时新建一个对应"name"的数组, 内循环时当前数组不变
                    tempObj[nameArr[k]] = tempObj[nameArr[k]] || []
                    tempObj[nameArr[k]].push(initialArr[j])
                }
            }
        }
        for (let key in tempObj) {
            let arr = []
            tempObj[key].map(item => {
                tempObj[key] = arr;
                arr.push(item.fieldName)
            })
        }
        return tempObj
    }
    // 删除表字段
    const deleteChart = record => {
        removeFields({ fieldIDs: record.ID }).then(res => {
            if (res.msg === 'Ok' || res.msg === '') {
                notification.success({
                    message: '提示',
                    duration: 3,
                    description: '删除成功',
                });
                setFlag(flag + 1);
            } else {
                notification.error({
                    message: '提示',
                    duration: 3,
                    description: res.msg,
                });
            }
        });
    };
    // 返回上一级
    const back = () => {
        history.push('/platformCenter/bsmanger/tablemanger')
    }
    return (
        <div style={{ width: '100vm', height: 'calc(100vh - 100px) ', background: '#ffffff' }}>
            <Spin tip="loading..." spinning={treeLoading}>
            <div className={styles.config}><div className={styles.title}>{formObj}(字段配置)</div> <Button type="primary"  onClick={back}>返回</Button></div>  
                <Table
                    columns={columns}
                    dataSource={tableData}
                    // pagination={{ pageSize: 10 }}
                    scroll={{ x: 'max-content', y: '45rem' }}
                    size="small"
                    rowKey={(record, index) => `complete${record.tableID}${index}`}
                    pagination={{
                        showTotal: (total, range) =>
                            `第${range[0]}-${range[1]} 条/共 ${total} 条`,
                        pageSizeOptions: [10, 20, 50, 100],
                        defaultPageSize: 20,
                        showQuickJumper: true,
                        showSizeChanger: true,
                    }}
                />
            </Spin>
            <FieldEditor
                isVisible={isVisible}
                isType={isType}
                itemData={itemData}
                formObj1={formObj}
                onCancel={() => setIsVisible(false)}
                callBackSubmit={Submit}
            />
        </div>
    );
};
export default AddModal;
